@@ -11,7 +11,7 @@ use DateTime::Locale::Base;
 use DateTime::Locale::Catalog;
 use Params::Validate qw( validate validate_pos SCALAR );
 
-our $VERSION = '0.41';
+our $VERSION = '0.44';
 
 
 my %Class;
@@ -832,17 +832,16 @@ These are accessed by passing a name to C<< $locale->format_for(...)
 >>, where the name is a Java-style format specifier.
 
 The return value is a string suitable for passing to C<<
-$dt->strftime() >>, so you can do something like this:
+$dt->format_cldr() >>, so you can do something like this:
 
-  print $dt->strftime( $dt->locale()->format_for('MMMdd')
+  print $dt->format_cldr( $dt->locale()->format_for('MMMdd') )
 
 which for the "en" locale would print out something like "08 Jul".
 
-Note that the localization goes beyond just directly translating the
-Java-style string to a strftime-style string. It may also include
-additional text specific to the locale. For example, the "MMMMd"
-format for the "zh" locale includes the Chinese characters for "day"
-(日) and month (月), so you get something like "8月23日".
+Note that the localization may also include additional text specific to the
+locale. For example, the "MMMMd" format for the "zh" locale includes the
+Chinese characters for "day" (日) and month (月), so you get something like "8
+月23日".
 
 =item * $locale->_available_format()
 
@@ -891,6 +890,27 @@ and corrections to the DateTime mailing list, datetime@perl.org.
 Support for this module is provided via the datetime@perl.org email
 list. See http://lists.perl.org/ for more details.
 
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module,
+please consider making a "donation" to me via PayPal. I spend a lot of
+free time creating free software, and would appreciate any support
+you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order
+for me to continue working on this particular software. I will
+continue to do so, inasmuch as I have in the past, for as long as it
+interests me.
+
+Similarly, a donation made in this way will probably not make me work
+on this software much more, unless I get so many donations that I can
+consider working on free software full time, which seems unlikely at
+best.
+
+To donate, log into PayPal and send money to autarch@urth.org or use
+the button on this page:
+L<http://www.urth.org/~autarch/fs-donation.html>
+
 =head1 AUTHORS
 
 Richard Evans <rich@ridas.com>
@@ -901,9 +921,6 @@ These modules are loosely based on the DateTime::Language modules,
 which were in turn based on the Date::Language modules from Graham
 Barr's TimeDate distribution.
 
-Thanks to Rick Measham for providing the Java to strftime pattern
-conversion routines used during locale generation.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2003 Richard Evans. Copyright (c) 2004-2008 David
